@@ -3,9 +3,6 @@ import sys
 import logging
 from datetime import date
 
-LOG_TO_FILE=False
-LOG_DIR="logs"
-
 class bcolors:
     HEADER = '\033[95m'
     OKBLUE = '\033[94m'
@@ -19,21 +16,10 @@ class bcolors:
 
 class _Log():
     def __init__(self):
-        log_dir = LOG_DIR
-        if log_dir:
-            if LOG_TO_FILE and not os.path.exists(log_dir):
-                os.makedirs(log_dir)
+        logging.debug("magic")
         self.logger = logging.getLogger('mysqld-integration-test')
         self.logger.setLevel(logging.INFO)
 
-        now = date.today()
-#            if LOG_TO_FILE:
-#                filename = f'{os.path.abspath(log_dir)}/{now.strftime("%Y_%m_%d")}.log'
-#                hdlr = logging.FileHandler(filename)
-#                formatter = logging.Formatter("%(asctime)s - %(levelname)s: %(message)s")
-#                hdlr.setFormatter(formatter)
-#                self.logger.addHandler(hdlr)
-#        self.logger.addHandler(logging.StreamHandler(sys.stdout))
 
     def debug(self, msg):
         if self.logger:
