@@ -91,6 +91,10 @@ class Mysqld:
         cursor.close()
         cnx.close()
 
+        # Return specifics the user can use to connect to the test instance
+        return({'host': self.args.bind_address, 'port': self.args.port, 'username': self.args.username, 'password': self.args.password})
+
+
     def stop(self, _signal=signal.SIGTERM):
         self.terminate(_signal)
 
